%--------------------------------------------------------------------------
%   MODEL (1): Analtyical life-cycle model
%--------------------------------------------------------------------------

%% Setup

modelname = 'mod0';
figdir    = './../Figures/';

%% Parameters 
beta  = 0.95;     % Discount factor 
r     = 1/beta-1; % Interest rate 
a_1   = 0;        % Initial assets 
ages = [1,2,3];   % Ages 

y_j1 = [1, 1, 1];           % Life-cycle income path 1
y_j2 = [0.95, 1, 1.05];     % Life-cycle income path 2
y_j3 = [0.95, 1.10, 0.95];  % Life-cycle income path 3 

%% Choice functions 

c_1 = @(y_j) 1/(1 + beta + beta^2)*(a_1 + y_j(1) + y_j(2)./(1+r) + y_j(3)./(1+r)^2 );
c_2 = @(y_j) beta*(1+r)/(1 + beta + beta^2)*(a_1 + y_j(1) + y_j(2)./(1+r) + y_j(3)./(1+r)^2 );
c_3 = @(y_j) beta^2*(1+r)^2/(1 + beta + beta^2)*(a_1 + y_j(1) + y_j(2)./(1+r) + y_j(3)./(1+r)^2 );

a_2 = @(y_j) y_j(1) + a_1 - c_1(y_j);
a_3 = @(y_j) y_j(2) + a_2(y_j)*(1+r) - c_2(y_j);

%% Plot life-cycle patterns 

figure;

subplot(3,1,1)
plot(ages, y_j1, 'linewidth', 2, 'color', 'blue', 'Marker', 'o'); hold on;
plot(ages, y_j2, 'linewidth', 2, 'color', 'red', 'LineStyle', '--', 'Marker', '^');
plot(ages, y_j3, 'linewidth', 2, 'color', [0, 0.5, 0], 'LineStyle', ':', 'Marker', 's');
yy = ylim;
ylim([yy(1)*0.9, yy(2)*1.1])
xticks(ages)
title('Life-cycle income')
% % legend('Flat $y_j$', 'Rising $y_j$', 'Life-Cycle $y_j$', 'columns', 3);
% % legend boxoff 
set(gca,'box','off')

subplot(3,1,2)
plot(ages, [c_1(y_j1), c_2(y_j1), c_3(y_j1)], 'linewidth', 2, 'color', 'blue', 'Marker', 'o'); hold on;
plot(ages, [c_1(y_j2), c_2(y_j2), c_3(y_j2)], 'linewidth', 2, 'color', 'red', 'LineStyle', '--', 'Marker', '^');
plot(ages, [c_1(y_j3), c_2(y_j3), c_3(y_j3)], 'linewidth', 2, 'color', [0, 0.5, 0], 'LineStyle', ':', 'Marker', 's');
title('Life-cycle consumption')
yy = ylim;
ylim([yy(1)*0.9, yy(2)*1.1])
xticks(ages)
set(gca,'box','off')

subplot(3,1,3)
plot(ages, [a_2(y_j1), a_3(y_j1), 0], 'linewidth', 2, 'color', 'blue', 'Marker', 'o'); hold on;
plot(ages, [a_2(y_j2), a_3(y_j2), 0], 'linewidth', 2, 'color', 'red', 'LineStyle', '--', 'Marker', '^');
plot(ages, [a_2(y_j3), a_3(y_j3), 0], 'linewidth', 2, 'color', [0, 0.5, 0], 'LineStyle', ':', 'Marker', 's');
yy = ylim;
ylim([yy(1)-0.1*abs(yy(1)), yy(2)+0.1*abs(yy(2))])
xticks(ages)
title('Life-cycle assets')
set(gca,'box','off')



f_height_div  = 1.25;
func_latexfig(f_height_div)


filename = ['Figure_', modelname, '_lifecycle.pdf'];
exportgraphics(gcf, [figdir, filename]);

